<?php
/*
Plugin Name: Bad Behavior Log Reader
Version: 0.3(jm)
Plugin URI: http://www.elvery.net/drzax/
Description: Basic log reader for <a href="http://www.homelandstupidity.us/software/bad-behavior/">Bad Behavior</a> in WordPress
Author: Simon Elvery, with mods by Jonathan Murray
Author URI: http://www.elvery.net/drzax/
*/

/*
Note:  Simon Elvery wrote the basic plugin, which worked great
on older versions of BB.  I found this plugin after installing 
BB 2.0 for wordpress, and discovered a number of changes to the 
database that made this plugin unusable.  Since I wanted the 
functionality, and found no replacements, I have taken it upon 
myself to update the plugin for my own use.

Changed:
- Name of default database (wp_bad_behavior) vice (wp_bad_behavior_log)

- Updated field names (*in view):
-- id (sort order, not needed to view)
-- ip (the source of the 'visitor')*
-- date (date / time)*
-- request_method (GET)
-- request_uri (where they were headed)*
-- server_protocol (HTTP)
-- http_headers (all the ugly info)* (chunked)
-- user_agent (who they identified themselves as)*
-- request_entity (blank?)
-- key (this is the explanation key, not yet documented)*

- Added "Chunker", a small function to break up long strings so they don't screw up your layout (as much)

The original concept and credit for the plugin remains with Simon Elvery.
All rights to the original work remain the property of Simon Elvery.
I'm just a guy trying to learn about PHP, MySQL, and WordPress!
- Jonathan Murray
*/

function keyInfo($key) {
	$keyInfo_data = array(
		'00000000' => 'Suspicious, logged but not denied',
		'17566707' => 'An invalid request was received from your browser. This may be caused by a malfunctioning proxy server or browser privacy software.',
		'17f4e8c8' => 'You do not have permission to access this server.',
		'21f11d3f' => 'An invalid request was received. You claimed to be a mobile Web device, but you do not actually appear to be a mobile Web device.',
		'2b90f772' => 'You do not have permission to access this server. If you are using the Opera browser, then Opera must appear in your user agent.',
		'408d7e72' => 'You do not have permission to access this server. Before trying again, run anti-virus and anti-spyware software and remove any viruses and spyware from your computer.',
		'41feed15' => 'An invalid request was received. This may be caused by a malfunctioning proxy server. Bypass the proxy server and connect directly, or contact your proxy server administrator.',
		'45b35e30' => 'An invalid request was received from your browser. This may be caused by a malfunctioning proxy server or browser privacy software.',
		'57796684' => 'You do not have permission to access this server. Before trying again, run anti-virus and anti-spyware software and remove any viruses and spyware from your computer.',
		'582ec5e4' => 'An invalid request was received. If you are using a proxy server, bypass the proxy server or contact your proxy server administrator. This may also be caused by a bug in the Opera web browser.',
		'69920ee5' => 'An invalid request was received from your browser. This may be caused by a malfunctioning proxy server or browser privacy software.',
		'799165c2' => 'You do not have permission to access this server.',
		'7a06532b' => 'An invalid request was received from your browser. This may be caused by a malfunctioning proxy server or browser privacy software.',
		'7ad04a8a' => 'The automated program you are using is not permitted to access this server. Please use a different program or a standard Web browser.',
		'7d12528e' => 'You do not have permission to access this server.',
		'939a6fbb' => 'The proxy server you are using is not permitted to access this server. Please bypass the proxy server, or contact your proxy server administrator.',
		'9c9e4979' => 'The proxy server you are using is not permitted to access this server. Please bypass the proxy server, or contact your proxy server administrator.',
		'a0105122' => 'Expectation failed. Please retry your request.',
		'a1084bad' => 'You do not have permission to access this server.',
		'a52f0448' => 'An invalid request was received.  This may be caused by a malfunctioning proxy server or browser privacy software. If you are using a proxy server, bypass the proxy server or contact your proxy server administrator.',
		'b40c8ddc' => 'You do not have permission to access this server. Before trying again, close your browser, run anti-virus and anti-spyware software and remove any viruses and spyware from your computer.',
		'b7830251' => 'Your proxy server sent an invalid request. Please contact the proxy server administrator to have this problem fixed.',
		'b9cc1d86' => 'The proxy server you are using is not permitted to access this server. Please bypass the proxy server, or contact your proxy server administrator.',
		'c1fa729b' => 'You do not have permission to access this server. Before trying again, run anti-virus and anti-spyware software and remove any viruses and spyware from your computer.',
		'd60b87c7' => 'You do not have permission to access this server. Before trying again, please remove any viruses or spyware from your computer.',
		'dfd9b1ad' => 'You do not have permission to access this server.',
		'e4de0453' => 'An invalid request was received. You claimed to be a major search engine, but you do not appear to actually be a major search engine.',
		'e87553e1' => 'You do not have permission to access this server.',
		'f0dcb3fd' => 'You do not have permission to access this server. Before trying again, run anti-virus and anti-spyware software and remove any viruses and spyware from your computer.',
		'f1182195' => 'An invalid request was received. You claimed to be a major search engine, but you do not appear to actually be a major search engine.',
		'f9f2b8b9' => 'You do not have permission to access this server. This may be caused by a malfunctioning proxy server or browser privacy software.',
	);

	if (array_key_exists($key, $keyInfo_data)) return $keyInfo_data[$key];
	return array('00000000');
}


/* bastardized function to 'chunk' text string */
/* parameters:  (string to chunk), (how far into the string to chunk), (chunk size) */
function chunker($string, $max_length, $chunk){
  if (strlen($string) > $max_length) {
    $string = substr($string,$max_length - $chunk,$chunk);
  }
  else {
    $string = substr($string,$max_length - $chunk, strlen($string));
  }
return $string;
}

function bblr_display(){ 
	global $wpdb, $table_prefix;?>

	<table style="font-family:courier;" width="95%" cellpadding="2" cellspacing="2" border="0" summary="Bad Behavior Log">

    <tr>
      <th align="left">IP</th>
      <th align="left">Date</th>
      <th align="left">Request URI</th>
      <th align="left">Headers</th>
      <th align="left">User Agent</th>
      <th align="left">Message</th>
    </tr>

		<?php if ($log = $wpdb->get_results("SELECT * FROM ".$table_prefix."bad_behavior ORDER BY id DESC")): ?>

			<?php $alternate = '';?>
			<?php foreach ($log as $entry) : ?>
				<?php $alternate = ($alternate == '') ? 'alternate' : ''; ?>

				<tr class="<?php echo $alternate; ?>">

					<td style="font:12px Arial;white-space: nowrap;">
            <?php echo $entry->ip; ?>
          </td>

					<td style="font:12px Arial;">
            <?php echo $entry->date; ?>
          </td>

					<td style="font:12px Arial;white-space: nowrap;">
            <?php echo chunker($entry->request_uri, 20, 20); ?><br />
					  <?php echo chunker($entry->request_uri, 40, 20); ?><br />
					  <?php echo chunker($entry->request_uri, 60, 20); ?>
          </td>

					<td style="font:12px Arial;white-space: nowrap;">
            <?php echo chunker($entry->http_headers,  80, 80); ?><br />
            <?php echo chunker($entry->http_headers, 160, 80); ?><br />
            <?php echo chunker($entry->http_headers, 240, 80); ?>
          </td>

					<td style="font:12px Arial;white-space: nowrap;">
            <?php echo chunker($entry->user_agent, 40,40); ?><br />
            <?php echo chunker($entry->user_agent, 80,40); ?><br />
            <?php echo chunker($entry->user_agent,120,40); ?>
          </td>

					<td style="font:12px Arial;">
            <?php echo keyInfo($entry->key); ?>
          </td>
				</tr>
			<?php endforeach; ?>
		<?php else: ?>
			<tr><td colspan="6">There are no entries in the log.</td></tr>
		<?php endif; ?>
	</table>

	<?php
} //end function bblr_display

function bblr_add_menu(){	
	add_options_page('BB Log Reader', 'BB Log Reader', 8, __FILE__, 'bblr_display');
}

add_action('admin_menu', 'bblr_add_menu');	
?>
